/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.managementcenter.constructionProject.web;

import com.google.common.collect.Lists;
import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.sg.managementcenter.constructionProject.entity.ConstructionProject;
import com.jeeplus.modules.sg.managementcenter.constructionProject.service.ConstructionProjectService;
import com.jeeplus.modules.sg.managementcenter.constructionProject.util.ImportProUtil;
import com.jeeplus.modules.sg.managementcenter.constructionProject.util.ImportUtil;
import com.jeeplus.modules.sg.managementcenter.constructionProject.util.TreeTableUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;


@Controller
@RequestMapping(value = "${adminPath}/sg/managementCenter/constructionProject")
public class ConstructionProjectController extends BaseController {

	@Autowired
	private ConstructionProjectService constructionProjectService;
	
	@ModelAttribute
	public ConstructionProject get(@RequestParam(required=false) String id) {
		ConstructionProject entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = constructionProjectService.get(id);
		}
		if (entity == null){
			entity = new ConstructionProject();
		}
		return entity;
	}
	
	/**
	 * 项目列表页面
	 */
//	@RequiresPermissions("managementcenter:materialproject:list")
	@RequestMapping(value = {"list", ""})
	public String list(ConstructionProject constructionProject, Model model) {
		model.addAttribute("constructionProject", constructionProject);
		return "modules/sg/managementcenter/constructionProject/constructionList";
	}
	//树形列表页面
	@ResponseBody
	@RequestMapping(value = "bootstrapTreeTable")
	public List<Map<String,Object>> getBootstrapTreeTable(ConstructionProject constructionProject){
		List<Map<String,Object>> objects = Lists.newArrayList();
		List<ConstructionProject> constructionProjects = constructionProjectService.findList(constructionProject);
		List<Map<String, Object>> bootstrapTreeTables = TreeTableUtil.getBootstrapTreeTable(objects, constructionProjects);
		return bootstrapTreeTables;
	}
		/**
	 * 列表数据
	 */
	@ResponseBody
//	@RequiresPermissions("managementcenter:materialproject:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(ConstructionProject constructionProject, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<ConstructionProject> page = constructionProjectService.findPage(new Page<ConstructionProject>(request, response), constructionProject);
		return getBootstrapData(page);
	}

	/**
	 * 查看，增加，编辑表单页面
	 */
//	@RequiresPermissions(value={"managementcenter:materialproject:view","managementcenter:materialproject:add","managementcenter:materialproject:edit"},logical=Logical.OR)
	@RequestMapping(value = "form")
	public String form(ConstructionProject constructionProject, Model model) {
		model.addAttribute("constructionProject", constructionProject);
		return "modules/sg/managementcenter/materialproject/materialProjectForm";
	}

	/**
	 * 保存
	 */
	@ResponseBody
//	@RequiresPermissions(value={"managementcenter:materialproject:add","managementcenter:materialproject:edit"},logical=Logical.OR)
	@RequestMapping(value = "save")
	public AjaxJson save(ConstructionProject constructionProject, Model model) throws Exception{
		AjaxJson j = new AjaxJson();
		/**
		 * 后台hibernate-validation插件校验
		 */
		String errMsg = beanValidator(constructionProject);
		if (StringUtils.isNotBlank(errMsg)){
			j.setSuccess(false);
			j.setMsg(errMsg);
			return j;
		}
		//新增或编辑表单保存
		constructionProjectService.save(constructionProject);//保存
		j.setSuccess(true);
		j.setMsg("保存项目成功");
		return j;
	}
	
	/**
	 * 删除项目
	 */
	@ResponseBody
	@RequiresPermissions("managementcenter:materialproject:del")
	@RequestMapping(value = "delete")
	public AjaxJson delete(ConstructionProject constructionProject) {
		AjaxJson j = new AjaxJson();
		constructionProjectService.delete(constructionProject);
		j.setMsg("删除项目成功");
		return j;
	}
	
	/**
	 * 批量删除
	 */
	@ResponseBody
	@RequiresPermissions("managementcenter:materialproject:del")
	@RequestMapping(value = "deleteAll")
	public AjaxJson deleteAll(String ids) {
		AjaxJson j = new AjaxJson();
		String idArray[] =ids.split(",");
		for(String id : idArray){
			constructionProjectService.delete(constructionProjectService.get(id));
		}
		j.setMsg("删除项目成功");
		return j;
	}
	


	/**
	 * 导入Excel数据

	 */
	@ResponseBody
//	@RequiresPermissions("managementcenter:materialproject:import")
	@RequestMapping(value = "import")
	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request){
		AjaxJson j = new AjaxJson();
		try {
			ImportUtil importUtil = new ImportUtil(file, 0, 0);
			List<ConstructionProject> constructionProjects = ImportProUtil.getProjectUtil(importUtil);
			constructionProjectService.savaList(constructionProjects);
			j.setMsg( "已成功导入 "+constructionProjects.size()+" 条项目表单记录");
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入项目失败！失败信息："+e.getMessage());
		}
		return j;
	}
}